@@ -60,15 +60,32 @@ struct _BraseroBurnSession {
 struct _BraseroBurnSessionClass {
 	GObjectClass parent_class;
 
+	/** Virtual functions **/
+	BraseroBurnResult	(*set_output_image)	(BraseroBurnSession *session,
+							 BraseroImageFormat format,
+							 const gchar *image,
+							 const gchar *toc);
+	BraseroBurnResult	(*get_output_path)	(BraseroBurnSession *session,
+							 gchar **image,
+							 gchar **toc);
+	BraseroImageFormat	(*get_output_format)	(BraseroBurnSession *session);
+
 	/**
 	 * GObject signals could be used to warned of individual property
 	 * changes but since changing one property could change others
 	 * it's better to have one global signal and dialogs asking for
 	 * the session properties they are interested in.
 	 */
-	void			(*input_changed)	(BraseroBurnSession *session);
+	void			(*flags_changed)	(BraseroBurnSession *session);
+	void			(*track_added)		(BraseroBurnSession *session,
+							 BraseroTrack *track);
+	void			(*track_removed)	(BraseroBurnSession *session,
+							 BraseroTrack *track,
+							 guint former_position);
+	void			(*track_changed)	(BraseroBurnSession *session,
+							 BraseroTrack *track);
 	void			(*output_changed)	(BraseroBurnSession *session,
-							 BraseroMedium *medium);
+							 BraseroMedium *former_medium);
 };
 
 GType brasero_burn_session_get_type ();
@@ -82,11 +99,25 @@ BraseroBurnSession *brasero_burn_session_new ();
 
 BraseroBurnResult
 brasero_burn_session_add_track (BraseroBurnSession *session,
-				BraseroTrack *track);
+				BraseroTrack *track,
+				BraseroTrack *sibling);
+
+BraseroBurnResult
+brasero_burn_session_move_track (BraseroBurnSession *session,
+				 BraseroTrack *track,
+				 BraseroTrack *sibling);
+
+BraseroBurnResult
+brasero_burn_session_remove_track (BraseroBurnSession *session,
+				   BraseroTrack *track);
 
 GSList *
 brasero_burn_session_get_tracks (BraseroBurnSession *session);
 
+/**
+ * Get some information about the session
+ */
+
 BraseroBurnResult
 brasero_burn_session_get_status (BraseroBurnSession *session,
 				 BraseroStatus *status);
@@ -138,8 +169,7 @@ brasero_burn_session_set_image_output_full (BraseroBurnSession *session,
 BraseroBurnResult
 brasero_burn_session_get_output (BraseroBurnSession *session,
 				 gchar **image,
-				 gchar **toc,
-				 GError **error);
+				 gchar **toc);
 
 BraseroImageFormat
 brasero_burn_session_get_output_format (BraseroBurnSession *session);
@@ -187,7 +217,7 @@ brasero_burn_session_pop_settings (BraseroBurnSession *session);
 
 void
 brasero_burn_session_push_tracks (BraseroBurnSession *session);
-void
+BraseroBurnResult
 brasero_burn_session_pop_tracks (BraseroBurnSession *session);
 
 /**
@@ -227,6 +257,10 @@ brasero_burn_session_output_supported (BraseroBurnSession *session,
 BraseroMedia
 brasero_burn_session_get_required_media_type (BraseroBurnSession *session);
 
+guint
+brasero_burn_session_get_possible_output_formats (BraseroBurnSession *session,
+						  BraseroImageFormat *formats);
+
 BraseroImageFormat
 brasero_burn_session_get_default_output_format (BraseroBurnSession *session);
 
