@@ -94,7 +94,15 @@ extern void brasero_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:BOOLEAN,BOOLEAN (./libbrasero-marshal.list:12) */
+/* VOID:OBJECT,UINT (./libbrasero-marshal.list:12) */
+extern void brasero_marshal_VOID__OBJECT_UINT (GClosure     *closure,
+                                               GValue       *return_value,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint,
+                                               gpointer      marshal_data);
+
+/* VOID:BOOLEAN,BOOLEAN (./libbrasero-marshal.list:13) */
 extern void brasero_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -102,7 +110,7 @@ extern void brasero_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* VOID:DOUBLE,DOUBLE,LONG (./libbrasero-marshal.list:13) */
+/* VOID:DOUBLE,DOUBLE,LONG (./libbrasero-marshal.list:14) */
 extern void brasero_marshal_VOID__DOUBLE_DOUBLE_LONG (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -110,7 +118,7 @@ extern void brasero_marshal_VOID__DOUBLE_DOUBLE_LONG (GClosure     *closure,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
 
-/* VOID:POINTER,UINT,POINTER (./libbrasero-marshal.list:14) */
+/* VOID:POINTER,UINT,POINTER (./libbrasero-marshal.list:15) */
 extern void brasero_marshal_VOID__POINTER_UINT_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
