@@ -350,8 +350,7 @@ brasero_project_set_remove_button_state (BraseroProject *project)
 	gboolean sensitive;
 
 	sensitive = (project->priv->has_focus &&
-		    !project->priv->empty &&
-		     project->priv->selected_uris);
+	             project->priv->selected_uris);
 
 	action = gtk_action_group_get_action (project->priv->project_group, "DeleteProject");
 	gtk_action_set_sensitive (action, sensitive);
@@ -663,6 +662,7 @@ brasero_disc_get_use_info_notebook (BraseroProject *project)
 
 	/* The alignment to set properly the position of the GtkTextView */
 	alignment = gtk_alignment_new (0.5, 0.3, 0.0, 0.0);
+	gtk_container_set_border_width (GTK_CONTAINER (alignment), 10);
 	gtk_widget_show (alignment);
 	gtk_container_add (GTK_CONTAINER (event_box), alignment);
 
@@ -790,6 +790,7 @@ brasero_project_get_sectors_string (gint64 sectors,
 static void
 brasero_project_update_project_size (BraseroProject *project)
 {
+	BraseroTrackType *session_type;
 	goffset sectors = 0;
 	GtkWidget *status;
 	gchar *size_str;
@@ -807,9 +808,13 @@ brasero_project_update_project_size (BraseroProject *project)
 				       &sectors,
 				       NULL);
 
-	string = brasero_project_get_sectors_string (sectors, !BRASERO_IS_DATA_DISC (project->priv->current));
-	size_str = g_strdup_printf (_("Project estimated size: %s"), string);
+	session_type = brasero_track_type_new ();
+	brasero_burn_session_get_input_type (BRASERO_BURN_SESSION (project->priv->session), session_type);
 
+	string = brasero_project_get_sectors_string (sectors, !brasero_track_type_get_has_data (session_type));
+	brasero_track_type_free (session_type);
+
+	size_str = g_strdup_printf (_("Project estimated size: %s"), string);
 	g_free (string);
 
 	gtk_statusbar_push (GTK_STATUSBAR (status), project->priv->status_ctx, size_str);
@@ -825,7 +830,7 @@ brasero_project_update_controls (BraseroProject *project)
 	brasero_project_set_add_button_state (project);
 
 	action = gtk_action_group_get_action (project->priv->project_group, "DeleteAll");
-	gtk_action_set_sensitive (action, (project->priv->empty == FALSE));
+	gtk_action_set_sensitive (action, (brasero_disc_is_empty (BRASERO_DISC (project->priv->current))));
 }
 
 static void
@@ -980,7 +985,6 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 	}
 	else if (valid == BRASERO_SESSION_EMPTY) {
 		project->priv->empty = TRUE;
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (project->priv->help), 1);
 	}
 	else if (valid == BRASERO_SESSION_NO_OUTPUT) {
 		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
@@ -1021,6 +1025,9 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		project->priv->empty = FALSE;
 		project->priv->oversized = FALSE;
 	}
+
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (project->priv->help),
+	                               brasero_disc_is_empty (BRASERO_DISC (project->priv->current))? 0:1);
 }
 
 static void
@@ -1497,8 +1504,7 @@ brasero_project_reset (BraseroProject *project)
 
 	if (project->priv->project_status) {
 		gtk_widget_hide (project->priv->project_status);
-		gtk_dialog_response (GTK_DIALOG (project->priv->project_status),
-				     GTK_RESPONSE_CANCEL);
+		gtk_dialog_response (GTK_DIALOG (project->priv->project_status), GTK_RESPONSE_CANCEL);
 		project->priv->project_status = NULL;
 	}
 
@@ -2547,6 +2553,15 @@ brasero_project_save_session (BraseroProject *project,
 		return FALSE;
 	}
 
+	if (project->priv->empty) {
+		/* the project is empty anyway. No need to ask anything.
+		 * return FALSE since this is not a tmp project */
+		if (saved_uri)
+			*saved_uri = NULL;
+
+		return FALSE;
+	}
+
 	if (project->priv->project) {
 		GtkResponseType answer;
 
@@ -2580,15 +2595,6 @@ brasero_project_save_session (BraseroProject *project,
 		return FALSE;
 	}
 
-	if (project->priv->empty) {
-		/* the project is empty anyway. No need to ask anything.
-		 * return FALSE since this is not a tmp project */
-		if (saved_uri)
-			*saved_uri = NULL;
-
-		return FALSE;
-	}
-
     	if (project->priv->burnt) {
 		GtkResponseType answer;
 
